@@ -1,4 +1,4 @@
-# SPDX-FileCopyrightText: Copyright (c) 2022-2025 NVIDIA CORPORATION & AFFILIATES. All rights reserved.
+# SPDX-FileCopyrightText: Copyright (c) 2022-2024 NVIDIA CORPORATION & AFFILIATES. All rights reserved.
 # SPDX-License-Identifier: LicenseRef-NvidiaProprietary
 #
 # NVIDIA CORPORATION, its affiliates and licensors retain all intellectual
@@ -450,9 +450,8 @@ class Recipe:
         else:
             shutil.copy(nb_template, nb_output_file)
 
-    def add_notebook_helper_file(self, filename, dir=None):
-        """Copy the helper file from the provided directory
-        (by default from the lib directory) to the output directory,
+    def add_notebook_helper_file(self, filename):
+        """Copy the helper file from the lib directory to the output directory,
         where it can be accessed by the notebook generated by the
         create_notebook function.
 
@@ -461,9 +460,7 @@ class Recipe:
         filename : str
             Name of the helper file located in the lib directory.
         """
-        if dir is None:
-            dir = os.path.dirname(__file__)
-        filepath = os.path.join(dir, filename)
+        filepath = os.path.join(os.path.dirname(__file__), filename)
         if not os.path.exists(filepath):
             raise NotImplementedError(f"File {filepath} not found.")
 
